@@ -4,6 +4,10 @@ module WebMock
     def rSpecHashIncludingMatcher?(matcher)
       matcher.class.name =~ /R?Spec::Mocks::ArgumentMatchers::HashIncludingMatcher/
     end
+
+    def rSpecHashExcludingMatcher?(matcher)
+      matcher.class.name =~ /R?Spec::Mocks::ArgumentMatchers::HashExcludingMatcher/
+    end
   end
 
   class RequestPattern
@@ -37,7 +41,7 @@ module WebMock
     end
 
     def to_s
-      string = "#{@method_pattern.to_s.upcase}"
+      string = "#{@method_pattern.to_s.upcase}".dup
       string << " #{@uri_pattern.to_s}"
       string << " with body #{@body_pattern.to_s}" if @body_pattern
       string << " with headers #{@headers_pattern.to_s}" if @headers_pattern
@@ -115,10 +119,13 @@ module WebMock
     def add_query_params(query_params)
       @query_params = if query_params.is_a?(Hash)
         query_params
-      elsif query_params.is_a?(WebMock::Matchers::HashIncludingMatcher)
+      elsif query_params.is_a?(WebMock::Matchers::HashIncludingMatcher) \
+              || query_params.is_a?(WebMock::Matchers::HashExcludingMatcher)
         query_params
       elsif rSpecHashIncludingMatcher?(query_params)
         WebMock::Matchers::HashIncludingMatcher.from_rspec_matcher(query_params)
+      elsif rSpecHashExcludingMatcher?(query_params)
+        WebMock::Matchers::HashExcludingMatcher.from_rspec_matcher(query_params)
       else
         WebMock::Util::QueryMapper.query_to_values(query_params, notation: Config.instance.query_values_notation)
       end
@@ -148,16 +155,20 @@ module WebMock
     def matches?(uri)
       if @query_params.nil?
         # Let Addressable check the whole URI
-        WebMock::Util::URI.variations_of_uri_as_strings(uri).any? { |u| @pattern.match(u) }
+        matches_with_variations?(uri)
       else
         # WebMock checks the query, Addressable checks everything else
-        WebMock::Util::URI.variations_of_uri_as_strings(uri.omit(:query)).any? { |u| @pattern.match(u) } &&
+        matches_with_variations?(uri.omit(:query)) &&
           @query_params == WebMock::Util::QueryMapper.query_to_values(uri.query)
       end
     end
 
     def add_query_params(query_params)
-      warn "WebMock warning: ignoring query params in RFC 6570 template and checking them with WebMock"
+      @@add_query_params_warned ||= false
+      if not @@add_query_params_warned
+        @@add_query_params_warned = true
+        warn "WebMock warning: ignoring query params in RFC 6570 template and checking them with WebMock"
+      end
       super(query_params)
     end
 
@@ -166,6 +177,15 @@ module WebMock
       str += " with variables #{@pattern.variables.inspect}" if @pattern.variables
       str
     end
+
+    private
+
+    def matches_with_variations?(uri)
+      normalized_template = Addressable::Template.new(WebMock::Util::URI.heuristic_parse(@pattern.pattern))
+
+      WebMock::Util::URI.variations_of_uri_as_strings(uri, only_with_scheme: true)
+        .any? { |u| normalized_template.match(u) }
+    end
   end
 
   class URIStringPattern < URIPattern
@@ -232,7 +252,7 @@ module WebMock
 
       if (@pattern).is_a?(Hash)
         return true if @pattern.empty?
-        matching_hashes?(body_as_hash(body, content_type), @pattern)
+        matching_body_hashes?(body_as_hash(body, content_type), @pattern, content_type)
       elsif (@pattern).is_a?(WebMock::Matchers::HashIncludingMatcher)
         @pattern == body_as_hash(body, content_type)
       else
@@ -287,15 +307,16 @@ module WebMock
     #
     # @return [Boolean] true if the paramaters match the comparison
     #   hash, false if not.
-    def matching_hashes?(query_parameters, pattern)
+    def matching_body_hashes?(query_parameters, pattern, content_type)
       return false unless query_parameters.is_a?(Hash)
       return false unless query_parameters.keys.sort == pattern.keys.sort
       query_parameters.each do |key, actual|
         expected = pattern[key]
 
         if actual.is_a?(Hash) && expected.is_a?(Hash)
-          return false unless matching_hashes?(actual, expected)
+          return false unless matching_body_hashes?(actual, expected, content_type)
         else
+          expected = WebMock::Util::ValuesStringifier.stringify_values(expected) if url_encoded_body?(content_type)
           return false unless expected === actual
         end
       end
@@ -310,6 +331,9 @@ module WebMock
       Hash[WebMock::Util::HashKeysStringifier.stringify_keys!(hash, deep: true).sort]
     end
 
+    def url_encoded_body?(content_type)
+      content_type =~ %r{^application/x-www-form-urlencoded}
+    end
   end
 
   class HeadersPattern
@@ -333,6 +357,10 @@ module WebMock
       WebMock::Util::Headers.sorted_headers_string(@pattern)
     end
 
+    def pp_to_s
+      WebMock::Util::Headers.pp_headers_string(@pattern)
+    end
+
     private
 
     def empty_headers?(headers)
