@@ -63,6 +63,11 @@ shared_examples_for "stubbing requests" do |*adapter_info|
         stub_request(:get, "www.example.com").with(query: hash_including({"a" => ["b", "c"]})).to_return(body: "abc")
         expect(http_request(:get, "http://www.example.com/?a[]=b&a[]=c&b=1").body).to eq("abc")
       end
+
+      it 'should return stubbed response when stub expects exclude part of query params' do
+        stub_request(:get, 'www.example.com').with(query: hash_excluding(a: ['b', 'c'])).to_return(body: 'abc')
+        expect(http_request(:get, 'http://www.example.com/?a[]=c&a[]=d&b=1').body).to eq('abc')
+      end
     end
 
     describe "based on method" do
@@ -150,6 +155,32 @@ shared_examples_for "stubbing requests" do |*adapter_info|
               body: 'c[d][]=f&a=1&c[d][]=e')
             }.to raise_error(WebMock::NetConnectNotAllowedError, %r(Real HTTP connections are disabled. Unregistered request: POST http://www.example.com/ with body 'c\[d\]\[\]=f&a=1&c\[d\]\[\]=e'))
           end
+
+          describe "for request with form url encoded body and content type" do
+            it "should match if stubbed request body hash has string values matching string values in request body" do
+              WebMock.reset!
+              stub_request(:post, "www.example.com").with(body: {"foo" => '1'})
+              expect(http_request(
+                :post, "http://www.example.com/", headers: {'Content-Type' => 'application/x-www-form-urlencoded'},
+              body: "foo=1").status).to eq("200")
+            end
+
+            it "should match if stubbed request body hash has NON string values matching string values in request body" do
+              WebMock.reset!
+              stub_request(:post, "www.example.com").with(body: {"foo" => 1})
+              expect(http_request(
+                :post, "http://www.example.com/", headers: {'Content-Type' => 'application/x-www-form-urlencoded'},
+              body: "foo=1").status).to eq("200")
+            end
+
+            it "should match if stubbed request body is hash_included" do
+              WebMock.reset!
+              stub_request(:post, "www.example.com").with(body: {"foo" => hash_including("bar" => '1')})
+              expect(http_request(
+                       :post, "http://www.example.com/", headers: {'Content-Type' => 'application/x-www-form-urlencoded'},
+                       body: "foo[bar]=1").status).to eq("200")
+            end
+          end
         end
 
 
@@ -182,6 +213,30 @@ shared_examples_for "stubbing requests" do |*adapter_info|
               :post, "http://www.example.com/", headers: {'Content-Type' => 'application/json'},
             body: "{\"foo\":\"a b c\"}").status).to eq("200")
           end
+
+          it "should match if stubbed request body hash has NON string values matching NON string values in request body" do
+            WebMock.reset!
+            stub_request(:post, "www.example.com").with(body: {"foo" => 1})
+            expect(http_request(
+              :post, "http://www.example.com/", headers: {'Content-Type' => 'application/json'},
+            body: "{\"foo\":1}").status).to eq("200")
+          end
+
+          it "should not match if stubbed request body hash has string values matching NON string values in request body" do
+            WebMock.reset!
+            stub_request(:post, "www.example.com").with(body: {"foo" => '1'})
+            expect{http_request(
+              :post, "http://www.example.com/", headers: {'Content-Type' => 'application/json'},
+            body: "{\"foo\":1}") }.to raise_error(WebMock::NetConnectNotAllowedError)
+          end
+
+          it "should not match if stubbed request body hash has NON string values matching string values in request body" do
+            WebMock.reset!
+            stub_request(:post, "www.example.com").with(body: {"foo" => 1})
+            expect{http_request(
+              :post, "http://www.example.com/", headers: {'Content-Type' => 'application/json'},
+            body: "{\"foo\":\"1\"}") }.to raise_error(WebMock::NetConnectNotAllowedError)
+          end
         end
 
         describe "for request with xml body and content type is set to xml" do
