@@ -121,6 +121,12 @@ describe WebMock::RequestPattern do
         to match(WebMock::RequestSignature.new(:get, "www.example.com"))
     end
 
+    it "should match if Addressable::Template pattern that has ip address host matches request uri" do
+      signature = WebMock::RequestSignature.new(:get, "127.0.0.1:3000/1234")
+      uri = Addressable::Template.new("127.0.0.1:3000/{id}")
+      expect(WebMock::RequestPattern.new(:get, uri)).to match(signature)
+    end
+
     it "should match for uris with same parameters as pattern" do
       expect(WebMock::RequestPattern.new(:get, "www.example.com?a=1&b=2")).
         to match(WebMock::RequestSignature.new(:get, "www.example.com?a=1&b=2"))
